@@ -1,4 +1,6 @@
 from click.testing import CliRunner
+from setuptools_scm import get_version
+
 from east.__main__ import cli
 
 
@@ -6,9 +8,8 @@ def test_version():
     runner = CliRunner()
     result = runner.invoke(cli, ["--version"])
     assert result.exit_code == 0
-    assert "v0.0.0" in result.output
 
-
-if __name__ == "__main__":
-    test_version()
-    pass
+    assert (
+        get_version(version_scheme="post-release", local_scheme="no-local-version")
+        in result.output
+    )
